@@ -5,16 +5,24 @@ from .usbtmc_device_info import UsbTmcDeviceInfo
 from .usbtmc_device_address import UsbTmcDeviceAddress
 from .usbtmc_exception import *
 import usb.core
-import usb.backend.libusb1
-
-backend = usb.backend.libusb1.get_backend()
-if backend is None:
-    # No standard backend found, try loading one from libusb package
-    import libusb
-    backend = usb.backend.libusb1.get_backend(find_library=lambda x: libusb.dll._name)
-
+import usb.util
 
 class UsbTmcDevice(UsbTmcBase):
+    @classmethod
+    def get_backend(cls):
+        import usb.backend.libusb1
+        backend = usb.backend.libusb1.get_backend()
+
+        if backend is None:
+            # No standard backend found, try loading one from libusb package
+            try:
+                import libusb
+                backend = usb.backend.libusb1.get_backend(find_library=lambda x: libusb.dll._name)
+            except:
+                pass
+
+        return backend
+
     @classmethod
     def list_devices(cls, usb_vid: Optional[int] = None, usb_pid: Optional[int] = None) -> List[UsbTmcDeviceInfo]:
         def match(dev):
@@ -25,17 +33,20 @@ class UsbTmcDevice(UsbTmcBase):
                     bInterfaceSubClass=UsbTmcBase.USBTMC_INTERFACE_SUBCLASS)
 
                 if d is None:
-                    return False
-
-                if (usb_vid is not None) and (dev.idVendor != usb_vid):
-                    return False
-
-                if (usb_pid is not None) and (dev.idProduct != usb_pid):
+                    # Must have (at least) one interface with USBTMC_INTERFACE_CLASS/SUBCLASS
                     return False
 
                 return True
 
-        return [UsbTmcDeviceInfo.from_device(device) for device in usb.core.find(find_all=True, custom_match=match)]
+        # Get a backend for searching USB devices
+        backend = cls.get_backend()
+        matches = {'custom_match': match}
+        if usb_vid is not None: matches.update({'idVendor': usb_vid})
+        if usb_pid is not None: matches.update({'idProduct': usb_pid})
+
+        # usb.core.find returns an empty list when backend is None (i.e. no backend available)
+        # thus silently ignoring the UsbTmc list_devices functionality
+        return [UsbTmcDeviceInfo.from_device(device) for device in usb.core.find(backend=backend, find_all=True, **matches)]
 
     def __init__(self,
                  address: UsbTmcDeviceAddress,
@@ -51,20 +62,25 @@ class UsbTmcDevice(UsbTmcBase):
         self._transfer_btag_next = UsbTmcBase.DEFAULT_BTAG
         self._transfer_size_max = \
             transfer_size_max if transfer_size_max is not None else UsbTmcBase.DEFAULT_TRANSFER_SIZE_MAX
+        self._backend = self.get_backend()
+
+        if self._backend is None:
+            raise UsbTmcConnectionException('No suitable backend for USB communication found')
 
         # Open device
         if self._address.serial_number is not None:
-            self._device = usb.core.find(idVendor=self._address.vid, idProduct=self._address.pid,
+            self._device = usb.core.find(backend=self._backend,
+                                         idVendor=self._address.vid, idProduct=self._address.pid,
                                          serial_number=self._address.serial_number)
         else:
-            self._device = usb.core.find(idVendor=self._address.vid, idProduct=self._address.pid)
+            self._device = usb.core.find(backend=self._backend,
+                                         idVendor=self._address.vid, idProduct=self._address.pid)
 
         if self._device is None:
             raise UsbTmcConnectionException(
                 f'USB device with VID:PID {self._address.vid:04x}:{self._address.pid:04x}'
                 + (f' (serial number: {self._address.serial_number})' if self._address.serial_number is not None else '')
                 + ' was not found') from None
-            pass
 
         # find first USBTMC interface with matching INTERFACE_CLASS/SUBCLASS
         # and matching bInterfaceNumber (if it is given)
